"""Cython compilation utils for qubit_measurement_analysis package."""

# pylint: disable=broad-exception-caught
from pathlib import Path
import importlib.util
import subprocess
import sys


def check_cython_compiled() -> bool:
    """Check if Cython extensions are compiled."""
    extensions = [
        "qubit_measurement_analysis.cython._sspd",
        "qubit_measurement_analysis.cython._transformations",
        "qubit_measurement_analysis.cython.classification.cttp_utils",
    ]

    return all(importlib.util.find_spec(ext) is not None for ext in extensions)


def compile_cython():
    """Compile Cython extensions using setup.py."""
    try:
        # Get the path to setup.py in the cython directory
        cwd = Path(__file__).parent
        setup_py = cwd / "setup.py"

        if not setup_py.exists():
            print("Error: setup.py not found in cython directory")
            sys.exit(1)

        # Run compilation command with output displayed
        print(f"Compiling Cython extensions using {setup_py}")
        result = subprocess.run(
            [sys.executable, str(setup_py), "build_ext", "--inplace"],
            cwd=cwd,  # Set working directory to where setup.py is
            check=False,
        )

        if result.returncode != 0:
            print("Failed to compile Cython extensions")
            sys.exit(1)

    except Exception as e:
        print(f"Error during compilation: {str(e)}")
        sys.exit(1)
