"Setup functionality for C extension compiling"
# python setup.py build_ext --inplace

import os
import sys
from setuptools import setup, Extension
from Cython.Build import cythonize
import numpy as np

# Ensure the output directory exists
os.makedirs("classification", exist_ok=True)

# Set platform-specific compiler arguments
extra_compile_args = []
if sys.platform == "win32":
    extra_compile_args = ["/O2"]  # Windows MSVC optimization flag
else:
    extra_compile_args = ["-O3"]  # Unix-like systems

extensions = [
    Extension(
        "qubit_measurement_analysis.cython._sspd",
        ["_sspd.pyx"],
        include_dirs=[np.get_include()],
        extra_compile_args=extra_compile_args,
    ),
    Extension(
        "qubit_measurement_analysis.cython._transformations",
        ["_transformations.pyx"],
        include_dirs=[np.get_include()],
        extra_compile_args=extra_compile_args,
    ),
    Extension(
        "qubit_measurement_analysis.cython.classification.cttp_utils",
        ["classification/cttp_utils.pyx"],
        include_dirs=[np.get_include()],
        extra_compile_args=extra_compile_args,
    ),
]

setup(
    name="qubit_measurement_analysis",
    package_dir={"": "../.."},
    packages=[
        "qubit_measurement_analysis",
        "qubit_measurement_analysis.cython",
        "qubit_measurement_analysis.cython.classification",
    ],
    ext_modules=cythonize(extensions, language_level=3),
    include_dirs=[np.get_include()],
    entry_points={
        "console_scripts": [
            "qubit_measurement_analysis=qubit_measurement_analysis.cli:main",
        ],
    },
)
